==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicebus/kotlin/inputs/NWRuleSetIpRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicebus.kotlin.inputs

import com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs.builder
import com.pulumi.azurenative.servicebus.kotlin.enums.NetworkRuleIPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description of NetWorkRuleSet - IpRules resource.
 * @property action The IP Filter Action
 * @property ipMask IP Mask
 */
public data class NWRuleSetIpRulesArgs(
    public val action: Output<Either<String, NetworkRuleIPAction>>? = null,
    public val ipMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs =
        com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipMask(ipMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NWRuleSetIpRulesArgs].
 */
@PulumiTagMarker
public class NWRuleSetIpRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, NetworkRuleIPAction>>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("cemnlskfutmpqwta")
    public suspend fun action(`value`: Output<Either<String, NetworkRuleIPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("ehvltsnnaqgfpmps")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("dppeapjdjiiqwdyl")
    public suspend fun action(`value`: Either<String, NetworkRuleIPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("hkwcwcfqfofwlrjy")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("gufpmgbjgkuroqtu")
    public fun action(`value`: NetworkRuleIPAction) {
        val toBeMapped = Either.ofRight<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("scnpvkaesswbjuvx")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): NWRuleSetIpRulesArgs = NWRuleSetIpRulesArgs(
        action = action,
        ipMask = ipMask,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicebus/kotlin/inputs/NWRuleSetIpRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicebus.kotlin.inputs

import com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs.builder
import com.pulumi.azurenative.servicebus.kotlin.enums.NetworkRuleIPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description of NetWorkRuleSet - IpRules resource.
 * @property action The IP Filter Action
 * @property ipMask IP Mask
 */
public data class NWRuleSetIpRulesArgs(
    public val action: Output<Either<String, NetworkRuleIPAction>>? = null,
    public val ipMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs =
        com.pulumi.azurenative.servicebus.inputs.NWRuleSetIpRulesArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipMask(ipMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NWRuleSetIpRulesArgs].
 */
@PulumiTagMarker
public class NWRuleSetIpRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, NetworkRuleIPAction>>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("rpwvhornghpsmlul")
    public suspend fun action(`value`: Output<Either<String, NetworkRuleIPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("isqmpufxknoxgpjg")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("mowkpittiexubkfo")
    public suspend fun action(`value`: Either<String, NetworkRuleIPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("oxllicmbudlyytxi")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("hwqxesfnbjyxykyj")
    public fun action(`value`: NetworkRuleIPAction) {
        val toBeMapped = Either.ofRight<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("gbvyhwcgqhpadebq")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): NWRuleSetIpRulesArgs = NWRuleSetIpRulesArgs(
        action = action,
        ipMask = ipMask,
    )
}
